@@ -6,8 +6,12 @@ function openApplicationListSource(origin) {
     openPage("view-filter", origin, applicationListComp, { originFilter: origin, preferList: true })
 }
 
-function openCategory(icon, name, cat) {
-    openPage(icon, name, categoryComp, { category: cat })
+function openApplicationMime(mime) {
+    openPage("document-open-data", mime, applicationListComp, { mimeTypeFilter: mime })
+}
+
+function openCategory(cat) {
+    openPage(cat.icon, cat.name, categoryComp, { category: cat })
 }
 
 function openApplication(app) {
