@@ -20,27 +20,24 @@
 
 #include "AvailableView.h"
 
-#include <QtCore/QFile>
+// Qt includes
 #include <QtGui/QStackedWidget>
-#include <QtXml/QDomDocument>
 
+// KDE includes
 #include <KCategorizedSortFilterProxyModel>
 #include <KIcon>
 #include <KLocale>
 #include <KStandardDirs>
 
+// LibQApt includes
 #include <LibQApt/Backend>
 
+// Own includes
+#include <Category/Category.h>
 #include "ApplicationBackend.h"
 #include "BreadcrumbWidget/BreadcrumbWidget.h"
-#include "CategoryView/Category.h"
 #include "CategoryView/CategoryViewWidget.h"
 
-bool categoryLessThan(Category *c1, const Category *c2)
-{
-    return (QString::localeAwareCompare(c1->name(), c2->name()) < 0);
-}
-
 AvailableView::AvailableView(QWidget *parent, ApplicationBackend *appBackend)
         : AbstractViewContainer(parent)
         , m_backend(0)
@@ -48,11 +45,10 @@ AvailableView::AvailableView(QWidget *parent, ApplicationBackend *appBackend)
 {
 
     m_categoryViewWidget = new CategoryViewWidget(m_viewStack, m_appBackend);
-    populateCategories();
 
     QString rootName = i18n("Get Software");
     KIcon rootIcon = KIcon("applications-other");
-    m_categoryViewWidget->setCategories(m_categoryList, rootName, rootIcon);
+    m_categoryViewWidget->setCategories(Category::populateCategories(), rootName, rootIcon);
     m_breadcrumbWidget->setRootItem(m_categoryViewWidget->breadcrumbItem());
 
     m_viewStack->addWidget(m_categoryViewWidget);
@@ -77,33 +73,4 @@ void AvailableView::setBackend(QApt::Backend *backend)
     m_categoryViewWidget->setBackend(backend);
 }
 
-void AvailableView::populateCategories()
-{
-    qDeleteAll(m_categoryList);
-    m_categoryList.clear();
-    QFile menuFile(KStandardDirs::locate("appdata", "categories.xml"));
-
-    if (!menuFile.open(QIODevice::ReadOnly)) {
-        // Broken install or broken FS
-        return;
-    }
-
-    QDomDocument menuDocument;
-    QString error;
-    int line;
-    menuDocument.setContent(&menuFile, &error, &line);
-
-    QDomElement root = menuDocument.documentElement();
-
-    QDomNode node = root.firstChild();
-    while(!node.isNull())
-    {
-        m_categoryList << new Category(node);
-
-        node = node.nextSibling();
-    }
-
-    qSort(m_categoryList.begin(), m_categoryList.end(), categoryLessThan);
-}
-
 #include "AvailableView.moc"
