@@ -234,9 +234,14 @@ void MainWindow::reload()
 
     disconnect(m_updaterWidget, SIGNAL(packageChanged(QApt::Package*)),
                m_changelogWidget, SLOT(setPackage(QApt::Package*)));
+    m_isReloading = false;
+
     m_updaterWidget->reload();
+
     connect(m_updaterWidget, SIGNAL(packageChanged(QApt::Package*)),
             m_changelogWidget, SLOT(setPackage(QApt::Package*)));
+    m_isReloading = true;
+
     m_changelogWidget->setPackage(0);
     QApplication::restoreOverrideCursor();
 
